"""
Convenient management of datasets

- Placeholder
"""

__author__ = """Brendan Strejcek"""
__email__ = 'brendan@datagazing.com'
__version__ = '0.1.0'

# from .datashelf import SomeClass # noqa F401
